Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(419)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutView.cpp

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutView.cpp
diff --git a/third_party/WebKit/Source/core/layout/LayoutView.cpp b/third_party/WebKit/Source/core/layout/LayoutView.cpp
index f62c87aafa731a32b379d26cb4567f325c546df7..d53bfa3a34d27e3a9ea446beb27af4ed9b77ee3b 100644
--- a/third_party/WebKit/Source/core/layout/LayoutView.cpp
+++ b/third_party/WebKit/Source/core/layout/LayoutView.cpp
@@ -318,7 +318,7 @@ LayoutRect LayoutView::visualOverflowRect() const {
return layoutOverflowRect();
}
-LayoutRect LayoutView::localOverflowRectForPaintInvalidation() const {
+LayoutRect LayoutView::localVisualRect() const {
// TODO(wangxianzhu): This is only required without rootLayerScrolls (though
// it is also correct but unnecessary with rootLayerScrolls) because of the
// special LayoutView overflow model.
@@ -486,7 +486,7 @@ bool LayoutView::mapToVisualRectInAncestorSpace(
if (LayoutBox* obj = owner->layoutBox()) {
if (!(mode & InputIsInFrameCoordinates)) {
// Intersect the viewport with the paint invalidation rect.
LayoutRect viewRectangle = viewRect();
if (visualRectFlags & EdgeInclusive) {
if (!rect.inclusiveIntersect(viewRectangle))
@@ -678,9 +678,9 @@ void LayoutView::setSelection(
// Blocks contain selected objects and fill gaps between them, either on the
// left, right, or in between lines and blocks.
// In order to get the paint invalidation rect right, we have to examine left,
// middle, and right rects individually, since otherwise the union of those
// rects might remain the same even when changes have occurred.
typedef HashMap<LayoutBlock*, SelectionState> SelectedBlockMap;
SelectedBlockMap oldSelectedBlocks;
// FIXME: |newSelectedBlocks| doesn't really need to store the SelectionState,
@@ -486,7 +486,7 @@ bool LayoutView::mapToVisualRectInAncestorSpace(
if (LayoutBox* obj = owner->layoutBox()) {
if (!(mode & InputIsInFrameCoordinates)) {
- // Intersect the viewport with the paint invalidation rect.
+ // Intersect the viewport with the visual rect.
LayoutRect viewRectangle = viewRect();
if (visualRectFlags & EdgeInclusive) {
@@ -678,9 +678,9 @@ void LayoutView::setSelection(
// Blocks contain selected objects and fill gaps between them, either on the
// left, right, or in between lines and blocks.
- // In order to get the paint invalidation rect right, we have to examine left,
- // middle, and right rects individually, since otherwise the union of those
- // rects might remain the same even when changes have occurred.
+ // In order to get the visual rect right, we have to examine left, middle, and
+ // right rects individually, since otherwise the union of those rects might
+ // remain the same even when changes have occurred.
typedef HashMap<LayoutBlock*, SelectionState> SelectedBlockMap;
SelectedBlockMap oldSelectedBlocks;
« no previous file with comments | « third_party/WebKit/Source/core/layout/LayoutView.h ('k') | third_party/WebKit/Source/core/layout/PaintInvalidationState.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698